@@ -21,9 +21,6 @@
 #include "common/dts.h"
 #include "common/endian.h"
 
-#define DTS_HEADER_MAGIC    0x7ffe8001
-#define DTS_HD_HEADER_MAGIC 0x64582025
-
 // ---------------------------------------------------------------------------
 
 struct channel_arrangement {
@@ -81,25 +78,40 @@ enum source_pcm_resolution {
   spr_invalid7
 };
 
+int
+find_dts_sync_word(const unsigned char *buf,
+                   unsigned int size) {
+  if (4 > size)
+    // not enough data for one header
+    return -1;
+
+  unsigned int offset = 0;
+  uint32_t sync_word  = get_uint32_be(buf);
+  while ((DTS_HEADER_MAGIC != sync_word) && ((offset + 4) < size)) {
+    sync_word = (sync_word << 8) | buf[offset + 4];
+    ++offset;
+  }
+
+  if (DTS_HEADER_MAGIC != sync_word)
+    // no header found
+    return -1;
+
+  return offset;
+}
+
 int
 find_dts_header_internal(const unsigned char *buf,
                          unsigned int size,
                          struct dts_header_s *dts_header,
                          bool allow_no_hd_search) {
-
   unsigned int size_to_search = size - 15;
   if (size_to_search > size) {
     // not enough data for one header
     return -1;
   }
 
-  int offset;
-  for (offset = 0; offset < size_to_search; ++offset)
-     // sync words appear aligned in the bit stream
-    if (get_uint32_be(buf + offset) == DTS_HEADER_MAGIC)
-      break;
-
-  if (offset >= size_to_search)
+  int offset = find_dts_sync_word(buf, size);
+  if (0 > offset)
     // no header found
     return -1;
 
@@ -241,7 +253,7 @@ find_dts_header_internal(const unsigned char *buf,
   dts_header->hd_type      = dts_header_t::DTSHD_NONE;
   dts_header->hd_part_size = 0;
 
-  int hd_offset            = offset + dts_header->frame_byte_size;
+  size_t hd_offset         = offset + dts_header->frame_byte_size;
 
   if ((hd_offset + 9) > size)
     return allow_no_hd_search ? offset : -1;
