@@ -6,23 +6,21 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: error.h 2802 2005-02-20 18:40:37Z mosu $
-
    class definitions for the error exception class
 
    Written by Moritz Bunkus <moritz@bunkus.org>.
 */
 
-#ifndef __ERROR_H
-#define __ERROR_H
+#ifndef __MTX_COMMON_ERROR_H
+#define __MTX_COMMON_ERROR_H
 
-#include <string>
+#include "common/common_pch.h"
 
-using namespace std;
 
 class MTX_DLL_API error_c {
-private:
-  string error;
+protected:
+  std::string error;
+
 public:
   error_c():
     error("unknown error") {
@@ -32,17 +30,20 @@ public:
     error(_error) {
   }
 
-  error_c(const string &_error):
+  error_c(const std::string &_error):
     error(_error) {
   }
 
-  const char *get_error() const {
-    return error.c_str();
+  error_c(const boost::format &format)
+    : error(format.str()) {
   }
 
-  operator const char *() const {
-    return error.c_str();
+  virtual ~error_c() {
+  }
+
+  virtual std::string get_error() const {
+    return error;
   }
 };
 
-#endif // __ERROR_H
+#endif // __MTX_COMMON_ERROR_H
