@@ -18,6 +18,7 @@
 #include <ebml/EbmlVoid.h>
 
 #include "common/ebml.h"
+#include "common/fs_sys_helpers.h"
 #include "common/kax_file.h"
 
 kax_file_c::kax_file_c(mm_io_cptr &in)
@@ -117,7 +118,6 @@ kax_file_c::read_one_element() {
 
   EbmlElement *l2 = NULL;
   l1->Read(*m_es.get_object(), EBML_INFO_CONTEXT(*callbacks), upper_lvl_el, l2, true);
-  delete l2;
 
   unsigned long element_size = get_element_size(l1);
   if (m_debug_resync)
@@ -130,7 +130,7 @@ kax_file_c::read_one_element() {
 bool
 kax_file_c::is_level1_element_id(vint_c id) const {
   const EbmlSemanticContext &context = EBML_CLASS_CONTEXT(KaxSegment);
-  for (int segment_idx = 0; EBML_CTX_SIZE(context) > segment_idx; ++segment_idx)
+  for (size_t segment_idx = 0; EBML_CTX_SIZE(context) > segment_idx; ++segment_idx)
     if (EBML_ID_VALUE(EBML_CTX_IDX_ID(context,segment_idx)) == id.m_value)
       return true;
 
@@ -160,18 +160,31 @@ kax_file_c::resync_to_level1_element_internal(uint32_t wanted_id) {
   m_resync_start_pos = m_in->getFilePointer();
 
   uint32_t actual_id = m_in->read_uint32_be();
+  int64_t start_time = get_current_time_millis();
+
+  mxinfo(boost::format(Y("%1%: Error in the Matroska file structure at position %2%. Resyncing to the next level 1 element.\n"))
+         % m_in->get_file_name() % m_resync_start_pos);
+
+  if (m_debug_resync)
+    mxinfo(boost::format("kax_file::resync_to_level1_element(): starting at %1% potential ID %|2$08x|\n") % m_resync_start_pos % actual_id);
 
   while (m_in->getFilePointer() < m_file_size) {
+    int64_t now = get_current_time_millis();
+    if ((now - start_time) >= 10000) {
+      mxinfo(boost::format("Still resyncing at position %1%.\n") % m_in->getFilePointer());
+      start_time = now;
+    }
+
     actual_id = (actual_id << 8) | m_in->read_uint8();
 
     if (   ((0 != wanted_id) && (wanted_id != actual_id))
         || ((0 == wanted_id) && !is_level1_element_id(vint_c(actual_id, 4))))
       continue;
 
-    int64_t current_start_pos = m_in->getFilePointer() - 4;
-    int64_t element_pos       = current_start_pos;
-    unsigned int num_headers  = 1;
-    bool valid_unknown_size   = false;
+    uint64_t current_start_pos = m_in->getFilePointer() - 4;
+    uint64_t element_pos       = current_start_pos;
+    unsigned int num_headers   = 1;
+    bool valid_unknown_size    = false;
 
     if (m_debug_resync)
       mxinfo(boost::format("kax_file::resync_to_level1_element(): byte-for-byte search, found level 1 ID %|2$x| at %1%\n") % current_start_pos % actual_id);
@@ -211,6 +224,7 @@ kax_file_c::resync_to_level1_element_internal(uint32_t wanted_id) {
     }
 
     if ((4 == num_headers) || valid_unknown_size) {
+      mxinfo(boost::format(Y("Resyncing successful at position %1%.\n")) % current_start_pos);
       m_in->setFilePointer(current_start_pos, seek_beginning);
       return read_next_level1_element(wanted_id);
     }
@@ -218,6 +232,8 @@ kax_file_c::resync_to_level1_element_internal(uint32_t wanted_id) {
     m_in->setFilePointer(current_start_pos + 4, seek_beginning);
   }
 
+  mxinfo(Y("Resync failed: no valid Matroska level 1 element found.\n"));
+
   return NULL;
 }
 
