@@ -138,6 +138,39 @@ slcopy(bit_cursor_c &r,
   }
 }
 
+void
+mpeg4::p10::slice_info_t::dump() {
+  mxinfo(boost::format("slice_info dump:\n"
+                       "  nalu_type:                  %1%\n"
+                       "  nal_ref_idc:                %2%\n"
+                       "  type:                       %3%\n"
+                       "  pps_id:                     %4%\n"
+                       "  frame_num:                  %5%\n"
+                       "  field_pic_flag:             %6%\n"
+                       "  bottom_field_flag:          %7%\n"
+                       "  idr_pic_id:                 %8%\n"
+                       "  pic_order_cnt_lsb:          %9%\n"
+                       "  delta_pic_order_cnt_bottom: %10%\n"
+                       "  delta_pic_order_cnt:        %11%\n"
+                       "  first_mb_in_slice:          %12%\n"
+                       "  sps:                        %13%\n"
+                       "  pps:                        %14%\n")
+         % static_cast<unsigned int>(nalu_type)
+         % static_cast<unsigned int>(nal_ref_idc)
+         % static_cast<unsigned int>(type)
+         % static_cast<unsigned int>(pps_id)
+         % frame_num
+         % field_pic_flag
+         % bottom_field_flag
+         % idr_pic_id
+         % pic_order_cnt_lsb
+         % delta_pic_order_cnt_bottom
+         % (delta_pic_order_cnt[0] << 8 | delta_pic_order_cnt[1])
+         % first_mb_in_slice
+         % sps
+         % pps);
+}
+
 void
 mpeg4::p10::nalu_to_rbsp(memory_cptr &buffer) {
   int pos, size = buffer->get_size();
@@ -396,7 +429,7 @@ mpeg4::p10::parse_pps(memory_cptr &buffer,
 */
 bool
 mpeg4::p10::extract_par(uint8_t *&buffer,
-                        int &buffer_size,
+                        size_t &buffer_size,
                         uint32_t &par_num,
                         uint32_t &par_den) {
   try {
@@ -410,14 +443,14 @@ mpeg4::p10::extract_par(uint8_t *&buffer,
     avcc.read(nalu, 5);
     new_avcc.write(nalu);
 
-    int num_sps = avcc.read_uint8();
+    unsigned int num_sps = avcc.read_uint8();
     new_avcc.write_uint8(num_sps);
     num_sps &= 0x1f;
     mxverb(4, boost::format("mpeg4_p10_extract_par: num_sps %1%\n") % num_sps);
 
-    int sps;
+    unsigned int sps;
     for (sps = 0; sps < num_sps; sps++) {
-      int length = avcc.read_uint16_be();
+      unsigned int length = avcc.read_uint16_be();
       if ((length + avcc.getFilePointer()) >= buffer_size)
         length = buffer_size - avcc.getFilePointer();
       avcc.read(nalu, length);
@@ -478,11 +511,15 @@ mpeg4::p10::compare_poc_by_dec(const poc_t &poc1,
 
 memory_cptr
 mpeg4::p10::avcc_to_nalus(const unsigned char *buffer,
-                          int size) {
+                          size_t size) {
   try {
     if (6 > size)
       throw false;
 
+    uint32_t marker = get_uint32_be(buffer);
+    if (((marker & 0xffffff00) == 0x00000100) || (0x00000001 == marker))
+      return clone_memory(buffer, size);
+
     mm_mem_io_c mem(buffer, size);
     byte_buffer_c nalus(size * 2);
 
@@ -490,17 +527,17 @@ mpeg4::p10::avcc_to_nalus(const unsigned char *buffer,
       throw false;
 
     mem.setFilePointer(4, seek_beginning);
-    int nal_size_size = 1 + (mem.read_uint8() & 3);
+    size_t nal_size_size = 1 + (mem.read_uint8() & 3);
     if (2 > nal_size_size)
       throw false;
 
-    int sps_or_pps;
+    size_t sps_or_pps;
     for (sps_or_pps = 0; 2 > sps_or_pps; ++sps_or_pps) {
-      int num = mem.read_uint8();
+      unsigned int num = mem.read_uint8();
       if (0 == sps_or_pps)
         num &= 0x1f;
 
-      int i;
+      size_t i;
       for (i = 0; num > i; ++i) {
         uint16_t element_size   = mem.read_uint16_be();
         memory_cptr copy_buffer = memory_c::alloc(element_size + 4);
@@ -537,8 +574,11 @@ mpeg4::p10::avc_es_parser_c::avc_es_parser_c()
   , m_ignore_nalu_size_length_errors(false)
   , m_discard_actual_frames(false)
   , m_num_slices_by_type(11, 0)
-  , m_debug_keyframe_detection(debugging_requested("avc_debug_keyframe_detection"))
+  , m_debug_keyframe_detection(debugging_requested("avc_keyframe_detection") || debugging_requested("avc_parser"))
+  , m_debug_nalu_types(debugging_requested("avc_nalu_types") || debugging_requested("avc_parser"))
 {
+  if (m_debug_nalu_types)
+    init_nalu_names();
 }
 
 mpeg4::p10::avc_es_parser_c::~avc_es_parser_c() {
@@ -648,21 +688,19 @@ mpeg4::p10::avc_es_parser_c::add_timecode(int64_t timecode) {
 
 void
 mpeg4::p10::avc_es_parser_c::write_nalu_size(unsigned char *buffer,
-                                             int size,
-                                             int nalu_size_length) {
-  int i;
-
-  if (-1 == nalu_size_length)
-    nalu_size_length = m_nalu_size_length;
+                                             size_t size,
+                                             int this_nalu_size_length) {
+  unsigned int nalu_size_length = -1 == this_nalu_size_length ? m_nalu_size_length : this_nalu_size_length;
 
   if (!m_ignore_nalu_size_length_errors && (size >= ((uint64_t)1 << (nalu_size_length * 8)))) {
-    int required_bytes = nalu_size_length + 1;
-    while (size >= (1 << (required_bytes * 8)))
+    unsigned int required_bytes = nalu_size_length + 1;
+    while (size >= (1u << (required_bytes * 8)))
       ++required_bytes;
 
     throw nalu_size_length_error_c(required_bytes);
   }
 
+  unsigned int i;
   for (i = 0; i < nalu_size_length; i++)
     buffer[i] = (size >> (8 * (nalu_size_length - 1 - i))) & 0xff;
 }
@@ -677,6 +715,9 @@ mpeg4::p10::avc_es_parser_c::flush_decision(slice_info_t &si,
 
     if ((NALU_TYPE_IDR_SLICE == ref.nalu_type) && (si.idr_pic_id != ref.idr_pic_id))
       return true;
+
+    if (NALU_TYPE_IDR_SLICE != ref.nalu_type)
+      return true;
   }
 
   if (si.frame_num != ref.frame_num)
@@ -787,7 +828,7 @@ mpeg4::p10::avc_es_parser_c::handle_sps_nalu(memory_cptr &nalu) {
     return;
   rbsp_to_nalu(nalu);
 
-  int i;
+  size_t i;
   for (i = 0; m_sps_info_list.size() > i; ++i)
     if (m_sps_info_list[i].id == sps_info.id)
       break;
@@ -817,7 +858,7 @@ mpeg4::p10::avc_es_parser_c::handle_pps_nalu(memory_cptr &nalu) {
     return;
   rbsp_to_nalu(nalu);
 
-  int i;
+  size_t i;
   for (i = 0; m_pps_info_list.size() > i; ++i)
     if (m_pps_info_list[i].id == pps_info.id)
       break;
@@ -878,6 +919,9 @@ mpeg4::p10::avc_es_parser_c::handle_nalu(memory_cptr nalu) {
 
   int type = *(nalu->get_buffer()) & 0x1f;
 
+  if (m_debug_nalu_types)
+    mxinfo(boost::format("NALU type 0x%|1$02x| (%2%) size %3%\n") % type % get_nalu_type_name(type) % nalu->get_size());
+
   switch (type) {
     case NALU_TYPE_SEQ_PARAM:
       flush_incomplete_frame();
@@ -931,7 +975,6 @@ mpeg4::p10::avc_es_parser_c::parse_slice(memory_cptr &buffer,
                                          slice_info_t &si) {
   try {
     bit_cursor_c r(buffer->get_buffer(), buffer->get_size());
-    int sps_idx, pps_idx;
 
     memset(&si, 0, sizeof(si));
 
@@ -954,6 +997,7 @@ mpeg4::p10::avc_es_parser_c::parse_slice(memory_cptr &buffer,
 
     si.pps_id = geread(r);      // pps_id
 
+    size_t pps_idx;
     for (pps_idx = 0; m_pps_info_list.size() > pps_idx; ++pps_idx)
       if (m_pps_info_list[pps_idx].id == si.pps_id)
         break;
@@ -963,7 +1007,7 @@ mpeg4::p10::avc_es_parser_c::parse_slice(memory_cptr &buffer,
     }
 
     pps_info_t &pps = m_pps_info_list[pps_idx];
-
+    size_t sps_idx;
     for (sps_idx = 0; m_sps_info_list.size() > sps_idx; ++sps_idx)
       if (m_sps_info_list[sps_idx].id == pps.sps_id)
         break;
@@ -1074,9 +1118,10 @@ mpeg4::p10::avc_es_parser_c::cleanup() {
   if (0 == sps.pic_order_cnt_type) {
     j = 0;
 
-    int prev_pic_order_cnt_msb =  0;
-    int prev_pic_order_cnt_lsb =  0;
-    int pic_order_cnt_msb      = -1;
+    unsigned int prev_pic_order_cnt_msb = 0;
+    unsigned int prev_pic_order_cnt_lsb = 0;
+    unsigned int pic_order_cnt_msb      = 0;
+    bool first                          = true;
 
     while (m_frames.end() != i) {
       slice_info_t &si = i->m_si;
@@ -1086,13 +1131,13 @@ mpeg4::p10::avc_es_parser_c::cleanup() {
         return;
       }
 
-      if (-1 == pic_order_cnt_msb)
-        pic_order_cnt_msb = 0;
+      if (first)
+        first = false;
 
-      else if ((si.pic_order_cnt_lsb < prev_pic_order_cnt_lsb) && ((prev_pic_order_cnt_lsb - si.pic_order_cnt_lsb) >= (1 << (sps.log2_max_pic_order_cnt_lsb - 1))))
+      else if ((si.pic_order_cnt_lsb < prev_pic_order_cnt_lsb) && ((prev_pic_order_cnt_lsb - si.pic_order_cnt_lsb) >= (1u << (sps.log2_max_pic_order_cnt_lsb - 1))))
         pic_order_cnt_msb = prev_pic_order_cnt_msb + (1 << sps.log2_max_pic_order_cnt_lsb);
 
-      else if ((si.pic_order_cnt_lsb > prev_pic_order_cnt_lsb) && ((si.pic_order_cnt_lsb - prev_pic_order_cnt_lsb) > (1 << (sps.log2_max_pic_order_cnt_lsb - 1))))
+      else if ((si.pic_order_cnt_lsb > prev_pic_order_cnt_lsb) && ((si.pic_order_cnt_lsb - prev_pic_order_cnt_lsb) > (1u << (sps.log2_max_pic_order_cnt_lsb - 1))))
         pic_order_cnt_msb = prev_pic_order_cnt_msb - (1 << sps.log2_max_pic_order_cnt_lsb);
 
       else
@@ -1116,8 +1161,8 @@ mpeg4::p10::avc_es_parser_c::cleanup() {
 
   std::sort(poc.begin(), poc.end(), compare_poc_by_poc);
 
-  int num_frames    = m_frames.size();
-  int num_timecodes = m_timecodes.size();
+  size_t num_frames    = m_frames.size();
+  size_t num_timecodes = m_timecodes.size();
 
   for (j = 0; num_frames > j; ++j, ++t) {
     poc[j].timecode = *t;
@@ -1230,3 +1275,28 @@ mpeg4::p10::avc_es_parser_c::dump_info() {
            % calc_adler32(frame.m_data->get_buffer(), frame.m_data->get_size()));
   }
 }
+
+std::string
+mpeg4::p10::avc_es_parser_c::get_nalu_type_name(int type) {
+  std::string name = m_nalu_names_by_type[type];
+  if (name.empty())
+    return "unknown";
+
+  return name;
+}
+
+void
+mpeg4::p10::avc_es_parser_c::init_nalu_names() {
+  m_nalu_names_by_type[NALU_TYPE_NON_IDR_SLICE] = "non IDR slice";
+  m_nalu_names_by_type[NALU_TYPE_DP_A_SLICE]    = "DP A slice";
+  m_nalu_names_by_type[NALU_TYPE_DP_B_SLICE]    = "DP B slice";
+  m_nalu_names_by_type[NALU_TYPE_DP_C_SLICE]    = "DP C slice";
+  m_nalu_names_by_type[NALU_TYPE_IDR_SLICE]     = "IDR slice";
+  m_nalu_names_by_type[NALU_TYPE_SEI]           = "SEI";
+  m_nalu_names_by_type[NALU_TYPE_SEQ_PARAM]     = "SEQ param";
+  m_nalu_names_by_type[NALU_TYPE_PIC_PARAM]     = "PIC param";
+  m_nalu_names_by_type[NALU_TYPE_ACCESS_UNIT]   = "access unit";
+  m_nalu_names_by_type[NALU_TYPE_END_OF_SEQ]    = "end of sequence";
+  m_nalu_names_by_type[NALU_TYPE_END_OF_STREAM] = "end of stream";
+  m_nalu_names_by_type[NALU_TYPE_FILLER_DATA]   = "filler";
+}
