@@ -29,8 +29,8 @@ public:
     side_by_side_left_first        =  1,
     top_bottom_right_first         =  2,
     top_bottom_left_first          =  3,
-    checkboard_right_first         =  4,
-    checkboard_left_first          =  5,
+    checkerboard_right_first       =  4,
+    checkerboard_left_first        =  5,
     row_interleaved_right_first    =  6,
     row_interleaved_left_first     =  7,
     column_interleaved_right_first =  8,
