@@ -9,16 +9,12 @@
    Written by Moritz Bunkus <moritz@bunkus.org>.
 */
 
-#include "common/os.h"
+#include "common/common_pch.h"
 
 #include <cassert>
 #include <iostream>
-#include <string>
-#include <vector>
 
-extern "C" {
 #include <avilib.h>
-}
 
 #include <ebml/EbmlHead.h>
 #include <ebml/EbmlSubHead.h>
@@ -29,7 +25,6 @@ extern "C" {
 #include <matroska/KaxChapters.h>
 
 #include "common/chapters/chapters.h"
-#include "common/common.h"
 #include "common/ebml.h"
 #include "common/mm_io.h"
 #include "common/kax_analyzer.h"
@@ -53,7 +48,7 @@ extract_chapters(const std::string &file_name,
     return;
   }
 
-  EbmlMaster *master = analyzer->read_all(KaxChapters::ClassInfos);
+  EbmlMaster *master = analyzer->read_all(EBML_INFO(KaxChapters));
   if (NULL == master)
     return;
 
