@@ -13,13 +13,11 @@
 #ifndef __XTR_AVI_H
 #define __XTR_AVI_H
 
-#include "os.h"
+#include "common/common_pch.h"
 
-extern "C" {
 #include <avilib.h>
-}
 
-#include "xtr_base.h"
+#include "extract/xtr_base.h"
 
 class xtr_avi_c: public xtr_base_c {
 public:
@@ -28,7 +26,7 @@ public:
   alBITMAPINFOHEADER *m_bih;
 
 public:
-  xtr_avi_c(const string &codec_id, int64_t tid, track_spec_t &tspec);
+  xtr_avi_c(const std::string &codec_id, int64_t tid, track_spec_t &tspec);
 
   virtual void create_file(xtr_base_c *master, KaxTrackEntry &track);
   virtual void handle_frame(memory_cptr &frame, KaxBlockAdditions *additions, int64_t timecode, int64_t duration, int64_t bref, int64_t fref,
