@@ -16,6 +16,7 @@
 
 #include "common/ebml.h"
 #include "common/matroska.h"
+#include "common/mm_write_cache_io.h"
 #include "common/strings/editing.h"
 #include "common/strings/formatting.h"
 #include "common/strings/parsing.h"
@@ -221,7 +222,7 @@ xtr_ssa_c::handle_frame(memory_cptr &frame,
   // that defines a different layout. So let's account for that.
 
   std::string line = "Dialogue: ";
-  int i;
+  size_t i;
   for (i = 0; i < m_ssa_format.size(); i++) {
     std::string format = m_ssa_format[i];
 
@@ -262,7 +263,7 @@ xtr_ssa_c::handle_frame(memory_cptr &frame,
 
 void
 xtr_ssa_c::finish_file() {
-  int i;
+  size_t i;
 
   // Sort the SSA lines according to their ReadOrder number and
   // write them.
@@ -324,7 +325,7 @@ xtr_usf_c::create_file(xtr_base_c *master,
       if (0 <= end_tag_pos)
         codec_private_mod.erase(end_tag_pos, end_tag.length());
 
-      m_out       = new mm_file_io_c(m_file_name, MODE_CREATE);
+      m_out       = mm_write_cache_io_c::open(m_file_name, 10 * 1024 * 1024);
       m_formatter = counted_ptr<xml_formatter_c>(new xml_formatter_c(m_out, m_sub_charset));
 
       m_formatter->set_doctype("USFSubtitles", "USFV100.dtd");
