@@ -13,16 +13,16 @@
 #ifndef __XTR_WAV_H
 #define __XTR_WAV_H
 
-#include "os.h"
+#include "common/os.h"
 
-#include "xtr_base.h"
+#include "extract/xtr_base.h"
 
 class xtr_wav_c: public xtr_base_c {
 private:
   wave_header m_wh;
 
 public:
-  xtr_wav_c(const string &codec_id, int64_t tid, track_spec_t &tspec);
+  xtr_wav_c(const std::string &codec_id, int64_t tid, track_spec_t &tspec);
 
   virtual void create_file(xtr_base_c *master, KaxTrackEntry &track);
   virtual void finish_file();
@@ -37,11 +37,11 @@ private:
   uint32_t m_number_of_samples;
   int m_extract_blockadd_level;
   binary m_version[2];
-  mm_file_io_c *m_corr_out;
+  mm_io_c *m_corr_out;
   int m_channels;
 
 public:
-  xtr_wavpack4_c(const string &codec_id, int64_t tid, track_spec_t &tspec);
+  xtr_wavpack4_c(const std::string &codec_id, int64_t tid, track_spec_t &tspec);
 
   virtual void create_file(xtr_base_c *master, KaxTrackEntry &track);
   virtual void handle_frame(memory_cptr &frame, KaxBlockAdditions *additions, int64_t timecode, int64_t duration, int64_t bref, int64_t fref,
