@@ -6,8 +6,6 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: flac_common.h 2711 2005-01-12 15:03:47Z mosu $
-
    FLAC helper functions
 
    Written by Moritz Bunkus <moritz@bunkus.org>.
@@ -16,25 +14,20 @@
 #ifndef __FLAC_COMMON_H
 #define __FLAC_COMMON_H
 
-#include "config.h"
+#include "common/common_pch.h"
 
 #if defined(HAVE_FLAC_FORMAT_H)
 
 #include <FLAC/format.h>
 
-#include "common.h"
-
 #define FLAC_HEADER_STREAM_INFO      1
 #define FLAC_HEADER_VORBIS_COMMENTS  2
 #define FLAC_HEADER_CUESHEET         4
 #define FLAC_HEADER_APPLICATION      8
 #define FLAC_HEADER_SEEKTABLE       16
 
-int
-flac_get_num_samples(unsigned char *buf, int size,
-                     FLAC__StreamMetadata_StreamInfo &stream_info);
-int
-flac_decode_headers(unsigned char *mem, int size, int num_elements, ...);
+int flac_get_num_samples(unsigned char *buf, int size, FLAC__StreamMetadata_StreamInfo &stream_info);
+int flac_decode_headers(unsigned char *mem, int size, int num_elements, ...);
 
 #endif /* HAVE_FLAC_FORMAT_H */
 
