@@ -26,7 +26,7 @@
 
 int
 ac3_reader_c::probe_file(mm_io_c *io,
-                         int64_t size,
+                         uint64_t size,
                          int64_t probe_size,
                          int num_headers) {
   try {
@@ -56,7 +56,7 @@ ac3_reader_c::ac3_reader_c(track_info_c &_ti)
     if (0 < tag_size_end)
       size -= tag_size_end;
 
-    int init_read_len = std::min(size - tag_size_start, (int64_t)AC3_READ_SIZE);
+    size_t init_read_len = std::min(size - tag_size_start, (int64_t)AC3_READ_SIZE);
 
     if (io->read(chunk->get_buffer(), init_read_len) != init_read_len)
       throw error_c(boost::format(Y("ac3_reader: Could not read %1% bytes.")) % AC3_READ_SIZE);
@@ -83,7 +83,7 @@ ac3_reader_c::~ac3_reader_c() {
 
 void
 ac3_reader_c::create_packetizer(int64_t) {
-  if (NPTZR() != 0)
+  if (!demuxing_requested('a', 0) || (NPTZR() != 0))
     return;
 
   add_packetizer(new ac3_packetizer_c(this, m_ti, ac3header.sample_rate, ac3header.channels, ac3header.bsid));
@@ -97,20 +97,15 @@ ac3_reader_c::read(generic_packetizer_c *,
   int64_t read_len        = std::min((int64_t)AC3_READ_SIZE, remaining_bytes);
   int num_read            = io->read(chunk->get_buffer(), read_len);
 
-  if (0 > num_read) {
-    PTZR0->flush();
-    return FILE_STATUS_DONE;
+  if (0 < num_read) {
+    PTZR0->process(new packet_t(new memory_c(chunk->get_buffer(), num_read, false)));
+    bytes_processed += num_read;
+
+    if (0 < (remaining_bytes - num_read))
+      return FILE_STATUS_MOREDATA;
   }
 
-  PTZR0->process(new packet_t(new memory_c(chunk->get_buffer(), num_read, false)));
-  bytes_processed += num_read;
-
-  if (0 < (remaining_bytes - num_read))
-    return FILE_STATUS_MOREDATA;
-
-  PTZR0->flush();
-
-  return FILE_STATUS_DONE;
+  return flush_packetizers();
 }
 
 int
