@@ -20,7 +20,7 @@
 
 int
 asf_reader_c::probe_file(mm_io_c *io,
-                         int64_t size) {
+                         uint64_t size) {
   try {
     if (4 > size)
       return 0;
