@@ -525,14 +525,18 @@ avi_reader_c::add_audio_demuxer(int aid) {
   demuxer.m_channels               = AVI_audio_channels(m_avi);
   demuxer.m_bits_per_sample        = AVI_audio_bits(m_avi);
 
-  m_ti.m_id                          = aid + 1;       // ID for this audio track.
-  m_ti.m_avi_block_align             = get_uint16_le(&wfe->n_block_align);
-  m_ti.m_avi_avg_bytes_per_sec       = get_uint32_le(&wfe->n_avg_bytes_per_sec);
-  m_ti.m_avi_samples_per_chunk       = get_uint32_le(&m_avi->stream_headers[aid].dw_scale);
-  m_ti.m_avi_sample_scale            = get_uint32_le(&m_avi->stream_headers[aid].dw_rate);
-  m_ti.m_avi_samples_per_sec         = demuxer.m_samples_per_second;
+  m_ti.m_id                        = aid + 1;       // ID for this audio track.
+  m_ti.m_avi_block_align           = get_uint16_le(&wfe->n_block_align);
+  m_ti.m_avi_avg_bytes_per_sec     = get_uint32_le(&wfe->n_avg_bytes_per_sec);
+  m_ti.m_avi_samples_per_chunk     = get_uint32_le(&m_avi->stream_headers[aid].dw_scale);
+  m_ti.m_avi_sample_scale          = get_uint32_le(&m_avi->stream_headers[aid].dw_rate);
+  m_ti.m_avi_samples_per_sec       = demuxer.m_samples_per_second;
 
-  if (get_uint16_le(&wfe->cb_size) > 0) {
+  if ((0xfffe == audio_format) && (get_uint16_le(&wfe->cb_size) >= (sizeof(alWAVEFORMATEXTENSION)))) {
+    alWAVEFORMATEXTENSIBLE *ext = reinterpret_cast<alWAVEFORMATEXTENSIBLE *>(wfe);
+    audio_format                = get_uint32_le(&ext->extension.guid.data1);
+
+  } else if (get_uint16_le(&wfe->cb_size) > 0) {
     m_ti.m_private_data              = (unsigned char *)(wfe + 1);
     m_ti.m_private_size              = get_uint16_le(&wfe->cb_size);
   } else {
@@ -599,7 +603,9 @@ avi_reader_c::create_aac_packetizer(int aid,
   bool aac_data_created  = false;
   bool headerless        = (AVI_audio_format(m_avi) != 0x706d);
 
-  if (0 == m_ti.m_private_size) {
+  if ((0 == m_ti.m_private_size)
+      || (   (0x706d                       == AVI_audio_format(m_avi))
+          && ((sizeof(alWAVEFORMATEX) + 7)  < m_ti.m_private_size))) {
     aac_data_created     = true;
     channels             = AVI_audio_channels(m_avi);
     sample_rate          = AVI_audio_rate(m_avi);
@@ -619,10 +625,6 @@ avi_reader_c::create_aac_packetizer(int aid,
     m_ti.m_private_data    = created_aac_data;
 
   } else {
-    if ((2 != m_ti.m_private_size) && (5 != m_ti.m_private_size))
-      mxerror_tid(m_ti.m_fname, aid + 1,
-                  boost::format(Y("This AAC track does not contain valid headers. The extra header size is %1% bytes, expected were 2 or 5 bytes.\n")) % m_ti.m_private_size);
-
     if (!parse_aac_data(m_ti.m_private_data, m_ti.m_private_size, profile, channels, sample_rate, output_sample_rate, is_sbr))
       mxerror_tid(m_ti.m_fname, aid + 1, Y("This AAC track does not contain valid headers. Could not parse the AAC information.\n"));
 
@@ -948,6 +950,11 @@ avi_reader_c::identify_audio() {
   for (i = 0; i < AVI_audio_tracks(m_avi); i++) {
     AVI_set_audio_track(m_avi, i);
     unsigned int audio_format = AVI_audio_format(m_avi);
+    alWAVEFORMATEX *wfe       = m_avi->wave_format_ex[i];
+    if ((0xfffe == audio_format) && (get_uint16_le(&wfe->cb_size) >= (sizeof(alWAVEFORMATEXTENSION)))) {
+      alWAVEFORMATEXTENSIBLE *ext = reinterpret_cast<alWAVEFORMATEXTENSIBLE *>(wfe);
+      audio_format = get_uint32_le(&ext->extension.guid.data1);
+    }
 
     std::string type
       = (0x0001 == audio_format) || (0x0003 == audio_format) ? "PCM"
