@@ -43,7 +43,7 @@ public:
 
 int
 corepicture_reader_c::probe_file(mm_text_io_c *io,
-                                 int64_t) {
+                                 uint64_t) {
   try {
     corepicture_xml_find_root_c root_finder(io);
 
@@ -179,6 +179,9 @@ corepicture_reader_c::end_element_cb(const char *name) {
 
 void
 corepicture_reader_c::create_packetizer(int64_t tid) {
+  if (!demuxing_requested('v', 0) || (NPTZR() != 0))
+    return;
+
   uint8 private_buffer[5];
   uint32 codec_used = 0;
   std::vector<corepicture_pic_t>::const_iterator picture;
@@ -225,12 +228,7 @@ corepicture_reader_c::read(generic_packetizer_c *ptzr,
     m_current_picture++;
   }
 
-  if (m_current_picture == m_pictures.end()) {
-    PTZR(m_ptzr)->flush();
-    return FILE_STATUS_DONE;
-  }
-
-  return FILE_STATUS_MOREDATA;
+  return m_current_picture == m_pictures.end() ? flush_packetizer(m_ptzr) : FILE_STATUS_MOREDATA;
 }
 
 int
