@@ -85,7 +85,7 @@ flac_eof_cb(const FLAC__StreamDecoder *,
 
 int
 flac_reader_c::probe_file(mm_io_c *io,
-                          int64_t size) {
+                          uint64_t size) {
   unsigned char data[4];
 
   if (4 > size)
@@ -157,7 +157,7 @@ flac_reader_c::~flac_reader_c() {
 
 void
 flac_reader_c::create_packetizer(int64_t) {
-  if (NPTZR() != 0)
+  if (!demuxing_requested('a', 0) || (NPTZR() != 0))
     return;
 
   add_packetizer(new flac_packetizer_c(this, m_ti, header, header_size));
@@ -252,31 +252,21 @@ flac_reader_c::parse_file() {
 file_status_e
 flac_reader_c::read(generic_packetizer_c *,
                     bool) {
-  unsigned char *buf;
-  int samples_here;
-
   if (current_block == blocks.end())
-    return FILE_STATUS_DONE;
+    return flush_packetizers();
 
-  buf = (unsigned char *)safemalloc(current_block->len);
+  memory_cptr buf = memory_c::alloc(current_block->len);
   file->setFilePointer(current_block->filepos);
-  if (file->read(buf, current_block->len) != current_block->len) {
-    safefree(buf);
-    PTZR0->flush();
-    return FILE_STATUS_DONE;
-  }
+  if (file->read(buf, current_block->len) != current_block->len)
+    return flush_packetizers();
 
-  samples_here = flac_get_num_samples(buf, current_block->len, stream_info);
-  PTZR0->process(new packet_t(new memory_c(buf, current_block->len, true), samples * 1000000000 / sample_rate));
+  unsigned int samples_here = flac_get_num_samples(buf->get_buffer(), current_block->len, stream_info);
+  PTZR0->process(new packet_t(buf, samples * 1000000000 / sample_rate));
 
   samples += samples_here;
   current_block++;
 
-  if (current_block == blocks.end()) {
-    PTZR0->flush();
-    return FILE_STATUS_DONE;
-  }
-  return FILE_STATUS_MOREDATA;
+  return (current_block == blocks.end()) ? flush_packetizers() : FILE_STATUS_MOREDATA;
 }
 
 FLAC__StreamDecoderReadStatus
@@ -371,7 +361,7 @@ flac_reader_c::identify() {
 
 int
 flac_reader_c::probe_file(mm_io_c *io,
-                          int64_t size) {
+                          uint64_t size) {
   unsigned char data[4];
 
   if (4 > size)
