@@ -45,6 +45,7 @@
 #include "common/ebml.h"
 #include "common/endian.h"
 #include "common/hacks.h"
+#include "common/iso639.h"
 #include "common/math.h"
 #include "common/matroska.h"
 #include "common/mm_io.h"
@@ -1159,6 +1160,9 @@ kax_reader_c::read_headers_tracks(mm_io_c *io,
     if (NULL != ktlanguage) {
       mxverb(2, boost::format("matroska_reader: |  + Language: %1%\n") % std::string(*ktlanguage));
       track->language = std::string(*ktlanguage);
+      int index       = map_to_iso639_2_code(track->language.c_str());
+      if (-1 != index)
+        track->language = iso639_languages[index].iso639_2_code;
     }
 
     KaxTrackName *ktname = FINDFIRST(ktentry, KaxTrackName);
@@ -1477,11 +1481,10 @@ kax_reader_c::create_video_packetizer(kax_track_t *t,
       t->handle_packetizer_pixel_dimensions();
       t->handle_packetizer_default_duration();
 
-    } else if ((t->codec_id == MKV_V_MSCOMP) && vc1::is_fourcc(t->v_fourcc)) {
-      mxinfo_tid(m_ti.m_fname, t->tnum, Y("Using the VC1 video output module.\n"));
-      set_track_packetizer(t, new vc1_video_packetizer_c(this, nti));
+    } else if ((t->codec_id == MKV_V_MSCOMP) && vc1::is_fourcc(t->v_fourcc))
+      create_vc1_video_packetizer(t, nti);
 
-    } else {
+    else {
       mxinfo_tid(m_ti.m_fname, t->tnum, Y("Using the video output module.\n"));
       set_track_packetizer(t, new video_packetizer_c(this, nti, t->codec_id.c_str(), t->v_frate, t->v_width, t->v_height));
     }
@@ -1868,6 +1871,16 @@ kax_reader_c::create_mpeg4_p10_video_packetizer(kax_track_t *t,
   set_track_packetizer(t, new mpeg4_p10_video_packetizer_c(this, nti, t->v_frate, t->v_width, t->v_height));
 }
 
+void
+kax_reader_c::create_vc1_video_packetizer(kax_track_t *t,
+                                          track_info_c &nti) {
+  mxinfo_tid(m_ti.m_fname, t->tnum, Y("Using the VC1 video output module.\n"));
+  set_track_packetizer(t, new vc1_video_packetizer_c(this, nti));
+
+  if ((NULL != t->private_data) && (sizeof(alBITMAPINFOHEADER) < t->private_size))
+    PTZR(t->ptzr)->process(new packet_t(new memory_c(reinterpret_cast<unsigned char *>(t->private_data) + sizeof(alBITMAPINFOHEADER), t->private_size - sizeof(alBITMAPINFOHEADER), false)));
+}
+
 void
 kax_reader_c::read_first_frames(kax_track_t *t,
                                 unsigned num_wanted) {
@@ -2217,6 +2230,9 @@ kax_reader_c::process_block_group(KaxCluster *cluster,
       } else {
         packet_cptr packet(new packet_t(data, m_last_timecode + i * frame_duration, block_duration, block_bref, block_fref));
 
+        if ((NULL != duration) && (0 == uint64(*duration)))
+          packet->duration_mandatory = true;
+
         if (NULL != codec_state)
           packet->codec_state = clone_memory(codec_state->GetBuffer(), codec_state->GetSize());
 
