@@ -28,7 +28,7 @@
 
 int
 mpeg_es_reader_c::probe_file(mm_io_c *io,
-                             int64_t size) {
+                             uint64_t size) {
   if (PROBESIZE > size)
     return 0;
 
@@ -116,8 +116,10 @@ mpeg_es_reader_c::probe_file(mm_io_c *io,
 }
 
 mpeg_es_reader_c::mpeg_es_reader_c(track_info_c &_ti)
-  throw (error_c):
-  generic_reader_c(_ti) {
+  throw (error_c)
+  : generic_reader_c(_ti)
+  , bytes_processed(0)
+{
 
   try {
     M2VParser parser;
@@ -171,7 +173,7 @@ mpeg_es_reader_c::~mpeg_es_reader_c() {
 void
 mpeg_es_reader_c::create_packetizer(int64_t) {
   generic_packetizer_c *m2vpacketizer;
-  if (NPTZR() != 0)
+  if (!demuxing_requested('v', 0) || (NPTZR() != 0))
     return;
 
   mxinfo_tid(m_ti.m_fname, 0, Y("Using the MPEG-1/2 video output module.\n"));
@@ -183,21 +185,20 @@ mpeg_es_reader_c::create_packetizer(int64_t) {
 file_status_e
 mpeg_es_reader_c::read(generic_packetizer_c *,
                        bool) {
-  unsigned char *chunk = (unsigned char *)safemalloc(20000);
-  int num_read         = io->read(chunk, 20000);
-  if (0 > num_read) {
-    safefree(chunk);
-    return FILE_STATUS_DONE;
+  int64_t bytes_to_read = std::min(static_cast<int64_t>(READ_SIZE), size - bytes_processed);
+  if (0 >= bytes_to_read)
+    return flush_packetizers();
+
+  memory_cptr chunk = memory_c::alloc(bytes_to_read);
+  int64_t num_read  = io->read(chunk, bytes_to_read);
+
+  if (0 < num_read) {
+    chunk->set_size(num_read);
+    PTZR0->process(new packet_t(chunk));
+    bytes_processed = io->getFilePointer();
   }
 
-  if (0 < num_read)
-    PTZR0->process(new packet_t(new memory_c(chunk, num_read, true)));
-  if (20000 > num_read)
-    PTZR0->flush();
-
-  bytes_processed = io->getFilePointer();
-
-  return 20000 > num_read ? FILE_STATUS_DONE : FILE_STATUS_MOREDATA;
+  return bytes_to_read > num_read ? flush_packetizers() : FILE_STATUS_MOREDATA;
 }
 
 bool
