@@ -23,7 +23,7 @@ protected:
   static int potential_packet_sizes[];
 
 public:
-  static bool probe_file(mm_io_c *io, int64_t size);
+  static bool probe_file(mm_io_c *io, uint64_t size);
 
 public:
   mpeg_ts_reader_c(track_info_c &n_ti): generic_reader_c(n_ti) { };
