@@ -19,7 +19,7 @@
 
 int
 srt_reader_c::probe_file(mm_text_io_c *io,
-                         int64_t) {
+                         uint64_t) {
   return srt_parser_c::probe(io);
 }
 
@@ -51,7 +51,7 @@ srt_reader_c::~srt_reader_c() {
 
 void
 srt_reader_c::create_packetizer(int64_t) {
-  if (NPTZR() != 0)
+  if (!demuxing_requested('s', 0) || (NPTZR() != 0))
     return;
 
   bool is_utf8 = m_io->get_byte_order() != BO_NONE;
@@ -63,17 +63,10 @@ srt_reader_c::create_packetizer(int64_t) {
 file_status_e
 srt_reader_c::read(generic_packetizer_c *,
                    bool) {
-  if (m_subs->empty())
-    return FILE_STATUS_DONE;
+  if (!m_subs->empty())
+    m_subs->process(PTZR0);
 
-  m_subs->process(PTZR0);
-
-  if (m_subs->empty()) {
-    flush_packetizers();
-    return FILE_STATUS_DONE;
-  }
-
-  return FILE_STATUS_MOREDATA;
+  return m_subs->empty() ? flush_packetizers() : FILE_STATUS_MOREDATA;
 }
 
 int
