@@ -24,7 +24,7 @@
 
 int
 ssa_reader_c::probe_file(mm_text_io_c *io,
-                         int64_t) {
+                         uint64_t) {
   return ssa_parser_c::probe(io);
 }
 
@@ -63,7 +63,7 @@ ssa_reader_c::~ssa_reader_c() {
 
 void
 ssa_reader_c::create_packetizer(int64_t) {
-  if (NPTZR() != 0)
+  if (!demuxing_requested('s', 0) || (NPTZR() != 0))
     return;
 
   std::string global = m_subs->get_global();
@@ -74,17 +74,10 @@ ssa_reader_c::create_packetizer(int64_t) {
 file_status_e
 ssa_reader_c::read(generic_packetizer_c *,
                    bool) {
-  if (m_subs->empty())
-    return FILE_STATUS_DONE;
+  if (!m_subs->empty())
+    m_subs->process((textsubs_packetizer_c *)PTZR0);
 
-  m_subs->process((textsubs_packetizer_c *)PTZR0);
-
-  if (m_subs->empty()) {
-    flush_packetizers();
-    return FILE_STATUS_DONE;
-  }
-
-  return FILE_STATUS_MOREDATA;
+  return m_subs->empty() ? flush_packetizers() : FILE_STATUS_MOREDATA;
 }
 
 int
@@ -99,7 +92,7 @@ ssa_reader_c::identify() {
   id_result_container("SSA/ASS");
   id_result_track(0, ID_RESULT_TRACK_SUBTITLES, "SSA/ASS");
 
-  int i;
+  size_t i;
   for (i = 0; i < g_attachments.size(); i++)
     id_result_attachment(g_attachments[i].ui_id, g_attachments[i].mime_type, g_attachments[i].data->get_size(), g_attachments[i].name, g_attachments[i].description);
 }
