@@ -23,7 +23,7 @@
 
 int
 tta_reader_c::probe_file(mm_io_c *io,
-                         int64_t size) {
+                         uint64_t size) {
   unsigned char buf[4];
 
   if (26 > size)
@@ -102,7 +102,7 @@ tta_reader_c::~tta_reader_c() {
 
 void
 tta_reader_c::create_packetizer(int64_t) {
-  if (NPTZR() != 0)
+  if (!demuxing_requested('a', 0) || (NPTZR() != 0))
     return;
 
   add_packetizer(new tta_packetizer_c(this, m_ti, get_uint16_le(&header.channels), get_uint16_le(&header.bits_per_sample), get_uint32_le(&header.sample_rate)));
@@ -113,15 +113,13 @@ file_status_e
 tta_reader_c::read(generic_packetizer_c *,
                    bool) {
   if (seek_points.size() <= pos)
-    return FILE_STATUS_DONE;
+    return flush_packetizers();
 
   unsigned char *buf = (unsigned char *)safemalloc(seek_points[pos]);
   int nread          = io->read(buf, seek_points[pos]);
 
-  if (0 >= nread) {
-    PTZR0->flush();
-    return FILE_STATUS_DONE;
-  }
+  if (0 >= nread)
+    return flush_packetizers();
   pos++;
 
   memory_cptr mem(new memory_c(buf, nread, true));
@@ -135,12 +133,7 @@ tta_reader_c::read(generic_packetizer_c *,
 
   bytes_processed += nread;
 
-  if (seek_points.size() <= pos) {
-    PTZR0->flush();
-    return FILE_STATUS_DONE;
-  }
-
-  return FILE_STATUS_MOREDATA;
+  return seek_points.size() <= pos ? flush_packetizers() : FILE_STATUS_MOREDATA;
 }
 
 int
