@@ -26,7 +26,7 @@
 
 int
 vc1_es_reader_c::probe_file(mm_io_c *io,
-                            int64_t size) {
+                            uint64_t size) {
   try {
     if (PROBESIZE > size)
       return 0;
@@ -88,7 +88,7 @@ vc1_es_reader_c::vc1_es_reader_c(track_info_c &n_ti)
 
 void
 vc1_es_reader_c::create_packetizer(int64_t) {
-  if (NPTZR() != 0)
+  if (!demuxing_requested('v', 0) || (NPTZR() != 0))
     return;
 
   add_packetizer(new vc1_video_packetizer_c(this, m_ti));
@@ -100,20 +100,15 @@ file_status_e
 vc1_es_reader_c::read(generic_packetizer_c *,
                       bool) {
   if (m_bytes_processed >= m_size)
-    return FILE_STATUS_DONE;
+    return flush_packetizers();
 
   int num_read = m_io->read(m_buffer->get_buffer(), READ_SIZE);
-  if (0 >= num_read)
-    return FILE_STATUS_DONE;
+  if (0 < num_read) {
+    PTZR0->process(new packet_t(new memory_c(m_buffer->get_buffer(), num_read)));
+    m_bytes_processed += num_read;
+  }
 
-  PTZR0->process(new packet_t(new memory_c(m_buffer->get_buffer(), num_read)));
-
-  m_bytes_processed += num_read;
-
-  if ((READ_SIZE != num_read) || (m_bytes_processed >= m_size))
-    PTZR0->flush();
-
-  return READ_SIZE == num_read ? FILE_STATUS_MOREDATA : FILE_STATUS_DONE;
+  return ((READ_SIZE != num_read) || (m_bytes_processed >= m_size)) ? flush_packetizers() : FILE_STATUS_MOREDATA;
 }
 
 int
