@@ -22,7 +22,7 @@
 
 int
 wavpack_reader_c::probe_file(mm_io_c *io,
-                             int64_t size) {
+                             uint64_t size) {
   wavpack_header_t header;
 
   try {
@@ -94,11 +94,10 @@ wavpack_reader_c::~wavpack_reader_c() {
 
 void
 wavpack_reader_c::create_packetizer(int64_t) {
-  uint16_t version_le;
-
-  if (NPTZR() != 0)
+  if (!demuxing_requested('a', 0) || (NPTZR() != 0))
     return;
 
+  uint16_t version_le;
   put_uint16_le(&version_le, header.version);
   m_ti.m_private_data = (unsigned char *)&version_le;
   m_ti.m_private_size = sizeof(uint16_t);
@@ -124,18 +123,14 @@ wavpack_reader_c::read(generic_packetizer_c *ptzr,
   while (dummy_meta.channel_count < meta.channel_count) {
     extra_frames_number++;
     block_size = wv_parse_frame(io, dummy_header, dummy_meta, false, false);
-    if (-1 == block_size) {
-      PTZR0->flush();
-      return FILE_STATUS_DONE;
-    }
+    if (-1 == block_size)
+      return flush_packetizers();
     data_size += block_size;
     io->skip(block_size);
   }
 
-  if (0 > data_size) {
-    PTZR0->flush();
-    return FILE_STATUS_DONE;
-  }
+  if (0 > data_size)
+    return flush_packetizers();
 
   data_size += 3 * sizeof(uint32_t);
   if (extra_frames_number)
@@ -160,10 +155,8 @@ wavpack_reader_c::read(generic_packetizer_c *ptzr,
       put_uint32_le(databuffer, block_size);
       databuffer += 4;
     }
-    if (io->read(databuffer, block_size) != block_size) {
-      PTZR0->flush();
-      return FILE_STATUS_DONE;
-    }
+    if (io->read(databuffer, block_size) != static_cast<size_t>(block_size))
+      return flush_packetizers();
     databuffer += block_size;
   }
 
@@ -181,10 +174,8 @@ wavpack_reader_c::read(generic_packetizer_c *ptzr,
       while (dummy_meta.channel_count < meta_correc.channel_count) {
         extra_frames_number++;
         block_size = wv_parse_frame(io_correc, dummy_header_correc, dummy_meta, false, false);
-        if (-1 == block_size) {
-          PTZR0->flush();
-          return FILE_STATUS_DONE;
-        }
+        if (-1 == block_size)
+          return flush_packetizers();
         data_size += block_size;
         io_correc->skip(block_size);
       }
@@ -221,7 +212,7 @@ wavpack_reader_c::read(generic_packetizer_c *ptzr,
           put_uint32_le(databuffer, block_size);
           databuffer += 4;
         }
-        if (io_correc->read(databuffer, block_size) != block_size) {
+        if (io_correc->read(databuffer, block_size) != static_cast<size_t>(block_size)) {
           delete io_correc;
           io_correc = NULL;
         }
