@@ -20,6 +20,7 @@
 #include "common/strings/parsing.h"
 #include "input/subtitles.h"
 #include "merge/output_control.h"
+#include "merge/packet_extensions.h"
 
 // ------------------------------------------------------------
 
@@ -28,7 +29,9 @@ subtitles_c::process(generic_packetizer_c *p) {
   if (empty() || (entries.end() == current))
     return;
 
-  p->process(new packet_t(new memory_c((unsigned char *)current->subs.c_str(), 0, false), current->start, current->end - current->start));
+  packet_cptr packet(new packet_t(new memory_c((unsigned char *)current->subs.c_str(), 0, false), current->start, current->end - current->start));
+  packet->extensions.push_back(packet_extension_cptr(new subtitle_number_packet_extension_c(current->number)));
+  p->process(packet);
   ++current;
 }
 
@@ -90,6 +93,8 @@ srt_parser_c::parse() {
   bool timecode_warning_printed = false;
   parser_state_e state          = STATE_INITIAL;
   int line_number               = 0;
+  unsigned int subtitle_number  = 0;
+  unsigned int timecode_number  = 0;
   std::string subtitles;
 
   m_io->setFilePointer(0, seek_beginning);
@@ -120,6 +125,7 @@ srt_parser_c::parse() {
         break;
       }
       state = STATE_TIME;
+      parse_uint(s, subtitle_number);
 
     } else if (STATE_TIME == state) {
       boost::match_results<std::string::const_iterator> matches;
@@ -154,7 +160,7 @@ srt_parser_c::parse() {
       // The previous entry is done now. Append it to the list of subtitles.
       if (!subtitles.empty()) {
         strip_back(subtitles, true);
-        add(start, end, subtitles.c_str());
+        add(start, end, timecode_number, subtitles.c_str());
       }
 
       // Calculate the start and end time in ns precision for the following entry.
@@ -195,19 +201,21 @@ srt_parser_c::parse() {
         timecode_warning_printed = true;
       }
 
-      previous_start = start;
-      subtitles      = "";
-      state          = STATE_SUBS;
+      previous_start  = start;
+      subtitles       = "";
+      state           = STATE_SUBS;
+      timecode_number = subtitle_number;
 
     } else if (STATE_SUBS == state) {
       if (!subtitles.empty())
         subtitles += "\n";
       subtitles += s;
 
-    } else if (boost::regex_match(s, number_re))
+    } else if (boost::regex_match(s, number_re)) {
       state = STATE_TIME;
+      parse_uint(s, subtitle_number);
 
-    else {
+    } else {
       if (!subtitles.empty())
         subtitles += "\n";
       subtitles += s;
@@ -216,7 +224,7 @@ srt_parser_c::parse() {
 
   if (!subtitles.empty()) {
     strip_back(subtitles, true);
-    add(start, end, subtitles.c_str());
+    add(start, end, timecode_number, subtitles.c_str());
   }
 
   sort();
@@ -322,7 +330,7 @@ ssa_parser_c::parse() {
         strip(m_format);
 
         // Let's see if "Actor" is used in the format instead of "Name".
-        int i;
+        size_t i;
         for (i = 0; m_format.size() > i; ++i)
           if (downcase(m_format[i]) == "actor") {
             name_field = "Actor";
@@ -379,7 +387,7 @@ ssa_parser_c::parse() {
           + get_element("Effect", fields)           + comma
           + recode_text(fields);
 
-        add(start, end, line);
+        add(start, end, num, line);
         num++;
 
         add_to_global = false;
@@ -418,7 +426,7 @@ ssa_parser_c::parse() {
 std::string
 ssa_parser_c::get_element(const char *index,
                           std::vector<std::string> &fields) {
-  int i;
+  size_t i;
 
   for (i = 0; i < m_format.size(); i++)
     if (m_format[i] == index)
@@ -490,12 +498,12 @@ ssa_parser_c::add_attachment_maybe(std::string &name,
   attachment_t attachment;
 
   std::string short_name = m_file_name;
-  int pos                = short_name.rfind('/');
+  size_t pos             = short_name.rfind('/');
 
-  if (0 < pos)
+  if (std::string::npos != pos)
     short_name.erase(0, pos + 1);
   pos = short_name.rfind('\\');
-  if (0 < pos)
+  if (std::string::npos != pos)
     short_name.erase(0, pos + 1);
 
   attachment.ui_id        = m_attachment_id;
@@ -503,7 +511,7 @@ ssa_parser_c::add_attachment_maybe(std::string &name,
   attachment.description  = (boost::format(SSA_SECTION_FONTS == section ? Y("Imported font from %1%") : Y("Imported picture from %1%")) % short_name).str();
   attachment.to_all_files = true;
 
-  int allocated           = 1024;
+  size_t allocated        = 1024;
   attachment.data         = memory_c::alloc(allocated);
   attachment.data->set_size(0);
 
@@ -537,8 +545,8 @@ ssa_parser_c::decode_chars(unsigned char c1,
                            unsigned char c3,
                            unsigned char c4,
                            memory_cptr &buffer,
-                           int bytes_to_add,
-                           int &allocated) {
+                           size_t bytes_to_add,
+                           size_t &allocated) {
   unsigned char bytes[3];
 
   uint32_t value = ((c1 - 33) << 18) + ((c2 - 33) << 12) + ((c3 - 33) << 6) + (c4 - 33);
@@ -561,7 +569,7 @@ ssa_parser_c::decode_chars(unsigned char c1,
 
 int64_t
 spu_extract_duration(unsigned char *data,
-                     int buf_size,
+                     size_t buf_size,
                      int64_t timecode) {
   uint32_t date, control_start, next_off, start_off, off;
   unsigned char type;
