@@ -262,26 +262,7 @@ generic_packetizer_c::set_tag_track_uid() {
   for (idx_tags = 0; m_ti.m_tags->ListSize() > idx_tags; ++idx_tags) {
     KaxTag *tag = (KaxTag *)(*m_ti.m_tags)[idx_tags];
 
-    size_t idx_tag;
-    for (idx_tag = 0; tag->ListSize() > idx_tag; idx_tag++) {
-      EbmlElement *el = (*tag)[idx_tag];
-
-      if (!is_id(el, KaxTagTargets))
-        continue;
-
-      KaxTagTargets *targets = static_cast<KaxTagTargets *>(el);
-      size_t idx_target      = 0;
-
-      while (targets->ListSize() > idx_target) {
-        EbmlElement *uid_el = (*targets)[idx_target];
-        if (is_id(uid_el, KaxTagTrackUID)) {
-          targets->Remove(idx_target);
-          delete uid_el;
-
-        } else
-          ++idx_target;
-      }
-    }
+    remove_track_uid_tag_targets(tag);
 
     GetChildAs<KaxTagTrackUID, EbmlUInteger>(GetChild<KaxTagTargets>(tag)) = m_huid;
 
@@ -576,7 +557,21 @@ generic_packetizer_c::set_video_stereo_mode(stereo_mode_c::mode stereo_mode,
   m_ti.m_stereo_mode_source = source;
 
   if ((NULL != m_track_entry) && (stereo_mode_c::unspecified != stereo_mode))
-    GetChildAs<KaxVideoStereoMode, EbmlUInteger>(GetChild<KaxTrackVideo>(*m_track_entry)) = m_ti.m_stereo_mode;
+    set_video_stereo_mode_impl(GetChild<KaxTrackVideo>(*m_track_entry), m_ti.m_stereo_mode);
+}
+
+void
+generic_packetizer_c::set_video_stereo_mode_impl(EbmlMaster &video,
+                                                 stereo_mode_c::mode stereo_mode) {
+  GetChildAs<KaxVideoStereoMode, EbmlUInteger>(video) = stereo_mode;
+  bool previous_stereo_mode                           = g_stereo_mode_used;
+
+  if (   (stereo_mode_c::mono        != stereo_mode)
+      && (stereo_mode_c::unspecified != stereo_mode))
+    g_stereo_mode_used = true;
+
+  if (!previous_stereo_mode)
+    rerender_ebml_head();
 }
 
 void
@@ -697,7 +692,7 @@ generic_packetizer_c::set_headers() {
       }
 
       if ((PARAMETER_SOURCE_NONE != m_ti.m_stereo_mode_source) && (stereo_mode_c::unspecified != m_ti.m_stereo_mode))
-        GetChildAs<KaxVideoStereoMode, EbmlUInteger>(video) = m_ti.m_stereo_mode;
+        set_video_stereo_mode_impl(video, m_ti.m_stereo_mode);
     }
 
   } else if (track_audio == m_htrack_type) {
@@ -1021,12 +1016,12 @@ generic_packetizer_c::apply_factory_full_queueing(packet_cptr_di &p_start) {
 void
 generic_packetizer_c::force_duration_on_last_packet() {
   if (m_packet_queue.empty()) {
-    mxverb_tid(2, m_ti.m_fname, m_ti.m_id, "force_duration_on_last_packet: packet queue is empty\n");
+    mxverb_tid(3, m_ti.m_fname, m_ti.m_id, "force_duration_on_last_packet: packet queue is empty\n");
     return;
   }
   packet_cptr &packet        = m_packet_queue.back();
   packet->duration_mandatory = true;
-  mxverb_tid(2, m_ti.m_fname, m_ti.m_id,
+  mxverb_tid(3, m_ti.m_fname, m_ti.m_id,
              boost::format("force_duration_on_last_packet: forcing at %1% with %|2$.3f|ms\n") % format_timecode(packet->timecode) % (packet->duration / 1000.0));
 }
 
@@ -1114,13 +1109,13 @@ generic_packetizer_c::is_compatible_with(output_compatibility_e compatibility) {
 
 //--------------------------------------------------------------------
 
-#define add_all_requested_track_ids(type, container)                                              \
+#define add_all_requested_track_ids(type, container)                                                       \
   for (std::map<int64_t, type>::const_iterator i = m_ti.container.begin(); m_ti.container.end() != i; ++i) \
     add_requested_track_id(i->first);
 
-#define add_all_requested_track_ids2(container) \
-  for (size_t i = 0; i < m_ti.container.size(); i++) \
-    add_requested_track_id(m_ti.container[i]);
+#define add_all_requested_track_ids2(container)                                                                            \
+  for (std::map<int64_t, bool>::const_iterator i = m_ti.container.m_items.begin(); m_ti.container.m_items.end() != i; ++i) \
+    add_requested_track_id(i->first);
 
 generic_reader_c::generic_reader_c(track_info_c &ti)
   : m_ti(ti)
@@ -1133,7 +1128,6 @@ generic_reader_c::generic_reader_c(track_info_c &ti)
   , m_num_subtitle_tracks(0)
   , m_reference_timecode_tolerance(0)
 {
-
   add_all_requested_track_ids2(m_atracks);
   add_all_requested_track_ids2(m_vtracks);
   add_all_requested_track_ids2(m_stracks);
@@ -1176,60 +1170,32 @@ generic_reader_c::read_all() {
 bool
 generic_reader_c::demuxing_requested(char type,
                                      int64_t id) {
-  std::vector<int64_t> *tracks = NULL;
+  item_selector_c<bool> *tracks = 'v' == type ? &m_ti.m_vtracks
+                                : 'a' == type ? &m_ti.m_atracks
+                                : 's' == type ? &m_ti.m_stracks
+                                : 'b' == type ? &m_ti.m_btracks
+                                : 'T' == type ? &m_ti.m_track_tags
+                                :               NULL;
 
-  if ('v' == type) {
-    if (m_ti.m_no_video)
-      return false;
-    tracks = &m_ti.m_vtracks;
-
-  } else if ('a' == type) {
-    if (m_ti.m_no_audio)
-      return false;
-    tracks = &m_ti.m_atracks;
-
-  } else if ('s' == type) {
-    if (m_ti.m_no_subs)
-      return false;
-    tracks = &m_ti.m_stracks;
-
-  } else if ('b' == type) {
-    if (m_ti.m_no_buttons)
-      return false;
-    tracks = &m_ti.m_btracks;
-
-  } else if ('T' == type) {
-    if (m_ti.m_no_track_tags)
-      return false;
-    tracks = &m_ti.m_track_tags;
-
-  } else
+  if (NULL == tracks)
     mxerror(boost::format(Y("pr_generic.cpp/generic_reader_c::demuxing_requested(): Invalid track type %1%.")) % type);
 
-  if (tracks->empty())
-    return true;
-
-  size_t i;
-  for (i = 0; i < tracks->size(); i++)
-    if ((*tracks)[i] == id)
-      return true;
-
-  return false;
+  return tracks->selected(id);
 }
 
 attach_mode_e
 generic_reader_c::attachment_requested(int64_t id) {
-  if (m_ti.m_no_attachments)
+  if (m_ti.m_attach_mode_list.none())
     return ATTACH_MODE_SKIP;
 
   if (m_ti.m_attach_mode_list.empty())
     return ATTACH_MODE_TO_ALL_FILES;
 
-  if (map_has_key(m_ti.m_attach_mode_list, id))
-    return m_ti.m_attach_mode_list[id];
+  if (m_ti.m_attach_mode_list.selected(id))
+    return m_ti.m_attach_mode_list.get(id);
 
-  if (map_has_key(m_ti.m_attach_mode_list, -1))
-    return m_ti.m_attach_mode_list[-1];
+  if (m_ti.m_attach_mode_list.selected(-1))
+    return m_ti.m_attach_mode_list.get(-1);
 
   return ATTACH_MODE_SKIP;
 }
@@ -1508,11 +1474,6 @@ generic_reader_c::add_available_track_ids() {
 track_info_c::track_info_c()
   : m_initialized(true)
   , m_id(0)
-  , m_no_audio(false)
-  , m_no_video(false)
-  , m_no_subs(false)
-  , m_no_buttons(false)
-  , m_no_track_tags(false)
   , m_disable_multi_file(false)
   , m_private_data(NULL)
   , m_private_size(0)
@@ -1534,7 +1495,6 @@ track_info_c::track_info_c()
   , m_stereo_mode_source(PARAMETER_SOURCE_NONE)
   , m_nalu_size_length(0)
   , m_no_chapters(false)
-  , m_no_attachments(false)
   , m_no_global_tags(false)
   , m_avi_block_align(0)
   , m_avi_samples_per_sec(0)
@@ -1563,11 +1523,6 @@ track_info_c::operator =(const track_info_c &src) {
   m_id                         = src.m_id;
   m_fname                      = src.m_fname;
 
-  m_no_audio                   = src.m_no_audio;
-  m_no_video                   = src.m_no_video;
-  m_no_subs                    = src.m_no_subs;
-  m_no_buttons                 = src.m_no_buttons;
-  m_no_track_tags              = src.m_no_track_tags;
   m_atracks                    = src.m_atracks;
   m_btracks                    = src.m_btracks;
   m_stracks                    = src.m_stracks;
@@ -1637,7 +1592,6 @@ track_info_c::operator =(const track_info_c &src) {
   m_attach_mode_list           = src.m_attach_mode_list;
 
   m_no_chapters                = src.m_no_chapters;
-  m_no_attachments             = src.m_no_attachments;
   m_no_global_tags             = src.m_no_global_tags;
 
   m_chapter_charset            = src.m_chapter_charset;
