@@ -34,6 +34,7 @@
 #include "common/smart_pointers.h"
 #include "common/stereo_mode.h"
 #include "common/strings/editing.h"
+#include "merge/item_selector.h"
 #include "merge/packet.h"
 #include "merge/timecode_factory.h"
 #include "merge/webm.h"
@@ -184,8 +185,7 @@ public:
 
   // Options used by the readers.
   std::string m_fname;
-  bool m_no_audio, m_no_video, m_no_subs, m_no_buttons, m_no_track_tags;
-  std::vector<int64_t> m_atracks, m_vtracks, m_stracks, m_btracks, m_track_tags;
+  item_selector_c<bool> m_atracks, m_vtracks, m_stracks, m_btracks, m_track_tags;
   bool m_disable_multi_file;
 
   // Options used by the packetizers.
@@ -250,9 +250,9 @@ public:
   std::map<int64_t, int> m_nalu_size_lengths;
   int m_nalu_size_length;
 
-  std::map<int64_t, attach_mode_e> m_attach_mode_list; // As given on the command line
+  item_selector_c<attach_mode_e> m_attach_mode_list; // As given on the command line
 
-  bool m_no_chapters, m_no_attachments, m_no_global_tags;
+  bool m_no_chapters, m_no_global_tags;
 
   // Some file formats can contain chapters, but for some the charset
   // cannot be identified unambiguously (*cough* OGM *cough*).
@@ -327,6 +327,9 @@ public:
   virtual void add_available_track_ids();
 
   virtual int64_t get_queued_bytes();
+  virtual bool is_simple_subtitle_container() {
+    return false;
+  }
 
   virtual file_status_e flush_packetizer(int num);
   virtual file_status_e flush_packetizer(generic_packetizer_c *ptzr);
@@ -553,6 +556,7 @@ public:
   virtual void set_video_pixel_cropping(int left, int top, int right, int bottom, parameter_source_e source);
   virtual void set_video_pixel_cropping(const pixel_crop_t &cropping, parameter_source_e source);
   virtual void set_video_stereo_mode(stereo_mode_c::mode stereo_mode, parameter_source_e source);
+  virtual void set_video_stereo_mode_impl(EbmlMaster &video, stereo_mode_c::mode stereo_mode);
 
   virtual void set_as_default_track(int type, int priority);
 
