@@ -190,67 +190,69 @@ mmg_dialog::~mmg_dialog() {
 
 void
 mmg_dialog::create_menus() {
+  const wxString dummy(wxU("dummy"));
+
   file_menu = new wxMenu();
-  file_menu->Append(ID_M_FILE_NEW);
-  file_menu->Append(ID_M_FILE_LOAD);
-  file_menu->Append(ID_M_FILE_SAVE);
+  file_menu->Append(ID_M_FILE_NEW,                   dummy);
+  file_menu->Append(ID_M_FILE_LOAD,                  dummy);
+  file_menu->Append(ID_M_FILE_SAVE,                  dummy);
   file_menu->AppendSeparator();
-  file_menu->Append(ID_M_FILE_SETOUTPUT);
+  file_menu->Append(ID_M_FILE_SETOUTPUT,             dummy);
   file_menu->AppendSeparator();
-  file_menu->Append(ID_M_FILE_OPTIONS);
+  file_menu->Append(ID_M_FILE_OPTIONS,               dummy);
   file_menu->AppendSeparator();
-  file_menu->Append(ID_M_FILE_HEADEREDITOR);
+  file_menu->Append(ID_M_FILE_HEADEREDITOR,          dummy);
   file_menu->AppendSeparator();
-  file_menu->Append(ID_M_FILE_EXIT);
+  file_menu->Append(ID_M_FILE_EXIT,                  dummy);
 
   file_menu_sep = false;
   update_file_menu();
 
   wxMenu *muxing_menu = new wxMenu();
-  muxing_menu->Append(ID_M_MUXING_START);
+  muxing_menu->Append(ID_M_MUXING_START,             dummy);
   muxing_menu->AppendSeparator();
-  muxing_menu->Append(ID_M_MUXING_SHOW_CMDLINE);
-  muxing_menu->Append(ID_M_MUXING_COPY_CMDLINE);
-  muxing_menu->Append(ID_M_MUXING_SAVE_CMDLINE);
-  muxing_menu->Append(ID_M_MUXING_CREATE_OPTIONFILE);
+  muxing_menu->Append(ID_M_MUXING_SHOW_CMDLINE,      dummy);
+  muxing_menu->Append(ID_M_MUXING_COPY_CMDLINE,      dummy);
+  muxing_menu->Append(ID_M_MUXING_SAVE_CMDLINE,      dummy);
+  muxing_menu->Append(ID_M_MUXING_CREATE_OPTIONFILE, dummy);
   muxing_menu->AppendSeparator();
-  muxing_menu->Append(ID_M_MUXING_ADD_TO_JOBQUEUE);
-  muxing_menu->Append(ID_M_MUXING_MANAGE_JOBS);
+  muxing_menu->Append(ID_M_MUXING_ADD_TO_JOBQUEUE,   dummy);
+  muxing_menu->Append(ID_M_MUXING_MANAGE_JOBS,       dummy);
   muxing_menu->AppendSeparator();
-  muxing_menu->Append(ID_M_MUXING_ADD_CLI_OPTIONS);
+  muxing_menu->Append(ID_M_MUXING_ADD_CLI_OPTIONS,   dummy);
 
   chapter_menu = new wxMenu();
-  chapter_menu->Append(ID_M_CHAPTERS_NEW);
-  chapter_menu->Append(ID_M_CHAPTERS_LOAD);
-  chapter_menu->Append(ID_M_CHAPTERS_SAVE);
-  chapter_menu->Append(ID_M_CHAPTERS_SAVETOKAX);
-  chapter_menu->Append(ID_M_CHAPTERS_SAVEAS);
+  chapter_menu->Append(ID_M_CHAPTERS_NEW,            dummy);
+  chapter_menu->Append(ID_M_CHAPTERS_LOAD,           dummy);
+  chapter_menu->Append(ID_M_CHAPTERS_SAVE,           dummy);
+  chapter_menu->Append(ID_M_CHAPTERS_SAVETOKAX,      dummy);
+  chapter_menu->Append(ID_M_CHAPTERS_SAVEAS,         dummy);
   chapter_menu->AppendSeparator();
-  chapter_menu->Append(ID_M_CHAPTERS_VERIFY);
+  chapter_menu->Append(ID_M_CHAPTERS_VERIFY,         dummy);
   chapter_menu_sep = false;
   update_chapter_menu();
 
   wxMenu *window_menu = new wxMenu();
-  window_menu->Append(ID_M_WINDOW_INPUT);
-  window_menu->Append(ID_M_WINDOW_ATTACHMENTS);
-  window_menu->Append(ID_M_WINDOW_GLOBAL);
+  window_menu->Append(ID_M_WINDOW_INPUT,             dummy);
+  window_menu->Append(ID_M_WINDOW_ATTACHMENTS,       dummy);
+  window_menu->Append(ID_M_WINDOW_GLOBAL,            dummy);
   window_menu->AppendSeparator();
-  window_menu->Append(ID_M_WINDOW_CHAPTEREDITOR);
+  window_menu->Append(ID_M_WINDOW_CHAPTEREDITOR,     dummy);
 
   wxMenu *help_menu = new wxMenu();
-  help_menu->Append(ID_M_HELP_HELP);
-  help_menu->Append(ID_M_HELP_ABOUT);
+  help_menu->Append(ID_M_HELP_HELP,                  dummy);
+  help_menu->Append(ID_M_HELP_ABOUT,                 dummy);
 #if defined(HAVE_CURL_EASY_H)
   help_menu->AppendSeparator();
-  help_menu->Append(ID_M_HELP_CHECK_FOR_UPDATES);
+  help_menu->Append(ID_M_HELP_CHECK_FOR_UPDATES,     dummy);
 #endif  // defined(HAVE_CURL_EASY_H)
 
   wxMenuBar *menu_bar = new wxMenuBar();
-  menu_bar->Append(file_menu,    wxEmptyString);
-  menu_bar->Append(muxing_menu,  wxEmptyString);
-  menu_bar->Append(chapter_menu, wxEmptyString);
-  menu_bar->Append(window_menu,  wxEmptyString);
-  menu_bar->Append(help_menu,    wxEmptyString);
+  menu_bar->Append(file_menu,                        dummy);
+  menu_bar->Append(muxing_menu,                      dummy);
+  menu_bar->Append(chapter_menu,                     dummy);
+  menu_bar->Append(window_menu,                      dummy);
+  menu_bar->Append(help_menu,                        dummy);
   SetMenuBar(menu_bar);
 }
 
@@ -1196,7 +1198,7 @@ mmg_dialog::on_chapters_load_last(wxCommandEvent &evt) {
   if ((evt.GetId() < ID_M_CHAPTERS_LOADLAST1) || (static_cast<size_t>(evt.GetId() - ID_M_CHAPTERS_LOADLAST1) >= last_chapters.size()))
     return;
 
-  notebook->SetSelection(4);
+  notebook->SetSelection(3);
   chapter_editor_page->load(last_chapters[evt.GetId() - ID_M_CHAPTERS_LOADLAST1]);
 }
 
@@ -1246,37 +1248,37 @@ mmg_dialog::update_chapter_menu() {
 
 void
 mmg_dialog::on_new_chapters(wxCommandEvent &evt) {
-  notebook->SetSelection(4);
+  notebook->SetSelection(3);
   chapter_editor_page->on_new_chapters(evt);
 }
 
 void
 mmg_dialog::on_load_chapters(wxCommandEvent &evt) {
-  notebook->SetSelection(4);
+  notebook->SetSelection(3);
   chapter_editor_page->on_load_chapters(evt);
 }
 
 void
 mmg_dialog::on_save_chapters(wxCommandEvent &evt) {
-  notebook->SetSelection(4);
+  notebook->SetSelection(3);
   chapter_editor_page->on_save_chapters(evt);
 }
 
 void
 mmg_dialog::on_save_chapters_to_kax_file(wxCommandEvent &evt) {
-  notebook->SetSelection(4);
+  notebook->SetSelection(3);
   chapter_editor_page->on_save_chapters_to_kax_file(evt);
 }
 
 void
 mmg_dialog::on_save_chapters_as(wxCommandEvent &evt) {
-  notebook->SetSelection(4);
+  notebook->SetSelection(3);
   chapter_editor_page->on_save_chapters_as(evt);
 }
 
 void
 mmg_dialog::on_verify_chapters(wxCommandEvent &evt) {
-  notebook->SetSelection(4);
+  notebook->SetSelection(3);
   chapter_editor_page->on_verify_chapters(evt);
 }
 
@@ -1468,7 +1470,7 @@ mmg_dialog::load_job_queue() {
 
   for (i = 0; i < static_cast<size_t>(num); i++) {
     cfg->SetPath(wxT("/jobs"));
-    s.Printf(wxT("%u"), i);
+    s.Printf(wxT("%u"), static_cast<unsigned int>(i));
     if (!cfg->HasGroup(s))
       continue;
     cfg->SetPath(s);
@@ -1681,7 +1683,7 @@ mmg_dialog::create_header_editor_window(const wxString &file_name) {
 
 void
 mmg_dialog::header_editor_frame_closed(header_editor_frame_c *frame) {
-  header_editor_frames.erase(find(header_editor_frames.begin(), header_editor_frames.end(), frame));
+  header_editor_frames.erase(mxfind(frame, header_editor_frames));
 }
 
 #if defined(HAVE_CURL_EASY_H)
