@@ -12,18 +12,15 @@
    Adapted from code by Moritz Bunkus <moritz@bunkus.org>.
 */
 
-#include <stdlib.h>
-#include <stdio.h>
-#include <string.h>
-#include <errno.h>
+#include "common/common_pch.h"
 
 #include <ogg/ogg.h>
 
-#include "common.h"
-#include "kate_common.h"
-#include "pr_generic.h"
-#include "p_kate.h"
-#include "matroska.h"
+#include "common/endian.h"
+#include "common/kate.h"
+#include "common/matroska.h"
+#include "merge/pr_generic.h"
+#include "output/p_kate.h"
 
 using namespace libmatroska;
 
@@ -33,18 +30,18 @@ kate_packetizer_c::kate_packetizer_c(generic_reader_c *p_reader,
                                      int global_size)
   throw (error_c)
   : generic_packetizer_c(p_reader, p_ti)
-  , m_global_data(new memory_c((unsigned char *)safememdup(global_data ? global_data : ti.private_data,
-                                                           global_data ? global_size : ti.private_size),
-                               global_data ? global_size : ti.private_size, true))
+  , m_global_data(new memory_c((unsigned char *)safememdup(global_data ? global_data : m_ti.m_private_data,
+                                                           global_data ? global_size : m_ti.m_private_size),
+                               global_data ? global_size : m_ti.m_private_size, true))
   , m_previous_timecode(0)
 {
   set_track_type(track_subtitle);
 
   // the number of headers to expect is stored in the first header
-  memory_cptr temp(new memory_c((unsigned char *)m_global_data->get(), m_global_data->get_size(), false));
-  vector<memory_cptr> blocks = unlace_memory_xiph(temp);
+  memory_cptr temp(new memory_c((unsigned char *)m_global_data->get_buffer(), m_global_data->get_size(), false));
+  std::vector<memory_cptr> blocks = unlace_memory_xiph(temp);
 
-  kate_parse_identification_header(blocks[0]->get(), blocks[0]->get_size(), m_kate_id);
+  kate_parse_identification_header(blocks[0]->get_buffer(), blocks[0]->get_size(), m_kate_id);
   if (blocks.size() != m_kate_id.nheaders)
     throw false;
 
@@ -62,7 +59,7 @@ kate_packetizer_c::set_headers() {
   set_codec_id(MKV_S_KATE);
 
   memory_cptr codec_private = lace_memory_xiph(m_headers);
-  set_codec_private(codec_private->get(), codec_private->get_size());
+  set_codec_private(codec_private->get_buffer(), codec_private->get_size());
 
   generic_packetizer_c::set_headers();
 }
@@ -71,20 +68,20 @@ int
 kate_packetizer_c::process(packet_cptr packet) {
   if (packet->data->get_size() < (1 + 3 * sizeof(int64_t))) {
     /* end packet is 1 byte long and has type 0x7f */
-    if ((packet->data->get_size() == 1) && (packet->data->get()[0] == 0x7f)) {
+    if ((packet->data->get_size() == 1) && (packet->data->get_buffer()[0] == 0x7f)) {
       packet->timecode           = m_previous_timecode;
       packet->duration           = 1;
       packet->duration_mandatory = true;
       add_packet(packet);
 
     } else
-      mxwarn_tid(ti.fname, ti.id, Y("Kate packet is too small and is being skipped.\n"));
+      mxwarn_tid(m_ti.m_fname, m_ti.m_id, Y("Kate packet is too small and is being skipped.\n"));
 
     return FILE_STATUS_MOREDATA;
   }
 
-  int64_t start_time         = get_uint64_le(packet->data->get() + 1);
-  int64_t duration           = get_uint64_le(packet->data->get() + 1 + sizeof(int64_t));
+  int64_t start_time         = get_uint64_le(packet->data->get_buffer() + 1);
+  int64_t duration           = get_uint64_le(packet->data->get_buffer() + 1 + sizeof(int64_t));
 
   double scaled_timecode     = start_time * (double)m_kate_id.gden / (double)m_kate_id.gnum;
   double scaled_duration     = duration   * (double)m_kate_id.gden / (double)m_kate_id.gnum;
@@ -105,15 +102,15 @@ kate_packetizer_c::process(packet_cptr packet) {
 
 connection_result_e
 kate_packetizer_c::can_connect_to(generic_packetizer_c *src,
-                                  string &error_message) {
+                                  std::string &error_message) {
   kate_packetizer_c *psrc = dynamic_cast<kate_packetizer_c *>(src);
   if (NULL == psrc)
     return CAN_CONNECT_NO_FORMAT;
 
-  if (   ((NULL == ti.private_data) && (NULL != src->ti.private_data))
-      || ((NULL != ti.private_data) && (NULL == src->ti.private_data))
-      || (ti.private_size != src->ti.private_size)) {
-    error_message = (boost::format(Y("The codec's private data does not match (lengths: %1% and %2%).")) % ti.private_size % src->ti.private_size).str();
+  if (   ((NULL == m_ti.m_private_data) && (NULL != src->m_ti.m_private_data))
+      || ((NULL != m_ti.m_private_data) && (NULL == src->m_ti.m_private_data))
+      || (m_ti.m_private_size != src->m_ti.m_private_size)) {
+    error_message = (boost::format(Y("The codec's private data does not match (lengths: %1% and %2%).")) % m_ti.m_private_size % src->m_ti.m_private_size).str();
     return CAN_CONNECT_MAYBE_CODECPRIVATE;
   }
 
