@@ -26,9 +26,14 @@ protected:
 public:
   mpeg4_p10_video_packetizer_c(generic_reader_c *p_reader, track_info_c &p_ti, double fps, int width, int height);
   virtual int process(packet_cptr packet);
+  virtual void set_headers();
 
   virtual connection_result_e can_connect_to(generic_packetizer_c *src, std::string &error_message);
 
+  virtual const char *get_format_name() {
+    return "AVC/h.264";
+  }
+
 protected:
   virtual void extract_aspect_ratio();
   virtual void setup_nalu_size_len_change();
