@@ -6,8 +6,6 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: p_passthrough.h 3838 2008-08-21 15:04:24Z mosu $
-
    class definition for the pass through output module
 
    Written by Moritz Bunkus <moritz@bunkus.org>.
@@ -16,17 +14,13 @@
 #ifndef __P_PASSTHROUGH_H
 #define __P_PASSTHROUGH_H
 
-#include "os.h"
+#include "common/common_pch.h"
 
-#include "common.h"
-#include "pr_generic.h"
+#include "merge/pr_generic.h"
 
 class passthrough_packetizer_c: public generic_packetizer_c {
-private:
-  int64_t packets_processed, bytes_processed;
-
 public:
-  passthrough_packetizer_c(generic_reader_c *_reader, track_info_c &_ti)
+  passthrough_packetizer_c(generic_reader_c *p_reader, track_info_c &p_ti)
     throw (error_c);
 
   virtual int process(packet_cptr packet);
@@ -35,8 +29,7 @@ public:
   virtual const char *get_format_name() {
     return "passthrough";
   }
-  virtual connection_result_e can_connect_to(generic_packetizer_c *src,
-                                             string &error_message);
+  virtual connection_result_e can_connect_to(generic_packetizer_c *src, std::string &error_message);
 };
 
 #endif // __P_PASSTHROUGH_H
