@@ -11,20 +11,15 @@
    Written by Moritz Bunkus <moritz@bunkus.org>.
 */
 
-#include <ctype.h>
-#include <stdlib.h>
-#include <stdio.h>
-#include <string.h>
-#include <errno.h>
+#include "common/common_pch.h"
 
 #include <matroska/KaxContentEncoding.h>
 
-#include "common.h"
-#include "compression.h"
-#include "matroska.h"
-#include "mm_io.h"
-#include "p_vobsub.h"
-#include "subtitles.h"
+#include "common/compression.h"
+#include "common/matroska.h"
+#include "common/mm_io.h"
+#include "input/subtitles.h"
+#include "output/p_vobsub.h"
 
 using namespace libmatroska;
 
@@ -46,11 +41,11 @@ vobsub_packetizer_c::~vobsub_packetizer_c() {
 void
 vobsub_packetizer_c::set_headers() {
   set_codec_id(MKV_S_VOBSUB);
-  set_codec_private(idx_data->get(), idx_data->get_size());
+  set_codec_private(idx_data->get_buffer(), idx_data->get_size());
 
   generic_packetizer_c::set_headers();
 
-  track_entry->EnableLacing(false);
+  m_track_entry->EnableLacing(false);
 }
 
 int
@@ -63,7 +58,7 @@ vobsub_packetizer_c::process(packet_cptr packet) {
 
 connection_result_e
 vobsub_packetizer_c::can_connect_to(generic_packetizer_c *src,
-                                    string &error_message) {
+                                    std::string &error_message) {
   vobsub_packetizer_c *vsrc;
 
   vsrc = dynamic_cast<vobsub_packetizer_c *>(src);
