@@ -6,8 +6,6 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: p_vobsub.h 3838 2008-08-21 15:04:24Z mosu $
-
    class definition for the VobSub output module
 
    Written by Moritz Bunkus <moritz@bunkus.org>.
@@ -16,12 +14,10 @@
 #ifndef __P_VOBSUB_H
 #define __P_VOBSUB_H
 
-#include "os.h"
+#include "common/common_pch.h"
 
-#include "common.h"
-#include "compression.h"
-#include "pr_generic.h"
-#include "smart_pointers.h"
+#include "common/compression.h"
+#include "merge/pr_generic.h"
 
 class vobsub_packetizer_c: public generic_packetizer_c {
 private:
@@ -41,7 +37,7 @@ public:
     return "VobSub";
   }
   virtual connection_result_e can_connect_to(generic_packetizer_c *src,
-                                             string &error_message);
+                                             std::string &error_message);
 };
 
 #endif // __P_VOBSUB_H
