@@ -11,14 +11,12 @@
    Written by Steve Lhomme <steve.lhomme@free.fr>.
 */
 
-#include "os.h"
+#include "common/common_pch.h"
 
-#include <string.h>
-#include <errno.h>
-
-#include "common.h"
-#include "matroska.h"
-#include "p_wavpack.h"
+#include "common/endian.h"
+#include "common/math.h"
+#include "common/matroska.h"
+#include "output/p_wavpack.h"
 
 using namespace libmatroska;
 
@@ -32,7 +30,7 @@ wavpack_packetizer_c::wavpack_packetizer_c(generic_reader_c *p_reader,
   , m_bits_per_sample(meta.bits_per_sample)
   , m_samples_per_block(meta.samples_per_block)
   , m_samples_output(0)
-  , m_has_correction(meta.has_correction && (htrack_max_add_block_ids != 0))
+  , m_has_correction(meta.has_correction && (0 != m_htrack_max_add_block_ids))
 {
   set_track_type(track_audio);
 }
@@ -40,7 +38,7 @@ wavpack_packetizer_c::wavpack_packetizer_c(generic_reader_c *p_reader,
 void
 wavpack_packetizer_c::set_headers() {
   set_codec_id(MKV_A_WAVPACK4);
-  set_codec_private(ti.private_data, ti.private_size);
+  set_codec_private(m_ti.m_private_data, m_ti.m_private_size);
   set_audio_sampling_freq((float)m_sample_rate);
   set_audio_channels(m_channels);
   set_audio_bit_depth(m_bits_per_sample);
@@ -49,12 +47,12 @@ wavpack_packetizer_c::set_headers() {
 
   generic_packetizer_c::set_headers();
 
-  track_entry->EnableLacing(!m_has_correction);
+  m_track_entry->EnableLacing(!m_has_correction);
 }
 
 int
 wavpack_packetizer_c::process(packet_cptr packet) {
-  int64_t samples = get_uint32_le(packet->data->get());
+  int64_t samples = get_uint32_le(packet->data->get_buffer());
 
   if (-1 == packet->duration)
     packet->duration = irnd(samples * 1000000000 / m_sample_rate);
@@ -72,7 +70,7 @@ wavpack_packetizer_c::process(packet_cptr packet) {
 
 connection_result_e
 wavpack_packetizer_c::can_connect_to(generic_packetizer_c *src,
-                                     string &error_message) {
+                                     std::string &error_message) {
   wavpack_packetizer_c *psrc = dynamic_cast<wavpack_packetizer_c *>(src);
   if (NULL == psrc)
     return CAN_CONNECT_NO_FORMAT;
