@@ -14,11 +14,10 @@
 #ifndef __P_WAVPACK_H
 #define __P_WAVPACK_H
 
-#include "os.h"
+#include "common/common_pch.h"
 
-#include "common.h"
-#include "pr_generic.h"
-#include "wavpack_common.h"
+#include "merge/pr_generic.h"
+#include "common/wavpack.h"
 
 class wavpack_packetizer_c: public generic_packetizer_c {
 private:
@@ -36,7 +35,7 @@ public:
   virtual const char *get_format_name() {
     return "WAVPACK4";
   }
-  virtual connection_result_e can_connect_to(generic_packetizer_c *src, string &error_message);
+  virtual connection_result_e can_connect_to(generic_packetizer_c *src, std::string &error_message);
 };
 
 #endif // __P_WAVPACK_H
