@@ -12,6 +12,10 @@
 
 #include <cassert>
 
+#include <matroska/KaxChapters.h>
+#include <matroska/KaxTag.h>
+#include <matroska/KaxTags.h>
+
 #include "propedit/options.h"
 #include "propedit/propedit.h"
 
@@ -69,6 +73,20 @@ options_c::add_target(const std::string &spec) {
   return add_target(target_c::tt_undefined, spec);
 }
 
+void
+options_c::add_tags(const std::string &spec) {
+  target_cptr target(new target_c(target_c::tt_tags));
+  target->parse_tags_spec(spec);
+  m_targets.push_back(target);
+}
+
+void
+options_c::add_chapters(const std::string &spec) {
+  target_cptr target(new target_c(target_c::tt_chapters));
+  target->parse_chapter_spec(spec);
+  m_targets.push_back(target);
+}
+
 void
 options_c::set_file_name(const std::string &file_name) {
   if (!m_file_name.empty())
@@ -126,14 +144,15 @@ options_c::remove_empty_targets() {
 
 template<typename T> static T*
 read_element(kax_analyzer_c *analyzer,
-             const std::string &category) {
+             const std::string &category,
+             bool require_existance = true) {
   int index = analyzer->find(T::ClassInfos.GlobalId);
   T *t      = NULL;
 
   if (-1 != index)
     t = dynamic_cast<T *>(analyzer->read_element(index));
 
-  if (NULL == t)
+  if ((NULL == t) && require_existance)
     mxerror(boost::format(Y("Modification of properties in the section '%1%' was requested, but no corresponding level 1 element was found in the file. %2%\n")) % category % FILE_NOT_MODIFIED);
 
   return t;
@@ -142,7 +161,9 @@ read_element(kax_analyzer_c *analyzer,
 void
 options_c::find_elements(kax_analyzer_c *analyzer) {
   KaxInfo *info     = NULL;
-  KaxTracks *tracks = NULL;
+  KaxTracks *tracks = read_element<KaxTracks>(analyzer, Y("Track headers"));
+  KaxTags *tags     = NULL;
+  KaxChapters *chapters = NULL;
 
   std::vector<target_cptr>::iterator target_it;
   mxforeach(target_it, m_targets) {
@@ -153,10 +174,26 @@ options_c::find_elements(kax_analyzer_c *analyzer) {
       target.set_level1_element(info);
 
     } else if (target_c::tt_track == target.m_type) {
-      if (NULL == tracks)
-        tracks = read_element<KaxTracks>(analyzer, Y("Track headers"));
       target.set_level1_element(tracks);
 
+    } else if (target_c::tt_tags == target.m_type) {
+      if (NULL == tags) {
+        tags = read_element<KaxTags>(analyzer, Y("Tags"), false);
+        if (NULL == tags)
+          tags = new KaxTags;
+      }
+
+      target.set_level1_element(tags, tracks);
+
+    } else if (target_c::tt_chapters == target.m_type) {
+      if (NULL == chapters) {
+        chapters = read_element<KaxChapters>(analyzer, Y("Chapters"), false);
+        if (NULL == chapters)
+          chapters = new KaxChapters;
+      }
+
+      target.set_level1_element(chapters, tracks);
+
     } else
       assert(false);
   }
